@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.024';
+our $VERSION   = '0.025';
 
 use Types::Standard 1.008003 -is, -types;
 use Types::TypeTiny qw(ArrayLike HashLike);
@@ -1079,7 +1079,7 @@ sub _build_method_signature_check {
 		else {
 			$type = shift(@sig);
 		}
-		if (is_HashRef($sig[0]) && !$sig[0]{slurpy}) {
+		if (is_HashRef($sig[0]) && !ref($sig[0]{slurpy})) {
 			$opts = shift(@sig);
 		}
 		
@@ -1105,7 +1105,19 @@ sub _build_method_signature_check {
 			}
 		}
 		
-		push @params, $is_named ? ($name, $type, $opts) : ($type, $opts);
+		my $hide_opts = 0;
+		if ($opts->{slurpy} && !ref($opts->{slurpy})) {
+			delete $opts->{slurpy};
+			$type = { slurpy => $type };
+			$hide_opts = 1;
+		}
+		
+		push(
+			@params,
+			$is_named
+				? ($name, $type, $hide_opts?():($opts))
+				: (       $type, $hide_opts?():($opts))
+		);
 	}
 	
 	my $next = $is_named ? \&Type::Params::compile_named_oo : \&Type::Params::compile;
@@ -2543,7 +2555,7 @@ and return the class name as a string.
   is_SpeciesClass($Dog);          # true
 
 Note that there is no B<Species> type created, but instead a pair of types
-is created: C<SpeciesClass> and C<SpeciesInstance>.
+is created: B<SpeciesClass> and B<SpeciesInstance>.
 
 It is also possible to inherit from generated classes.
 
